@@ -76,12 +76,9 @@
 	     (set! lines (cons (and (pair? (car x)) (pair-line-number (car x))) lines))
 	     (set! files (cons (and (pair? (car x)) (pair-filename (car x))) files)))))
 
-       ;; show the enclosing contexts
-       (let ((old-print-length (*s7* 'print-length)))
-	 (set! (*s7* 'print-length) 8)
+       (let-temporarily (((*s7* 'print-length) 8))
 	 (do ((e (outlet ow) (outlet e)))
-	     ((memq e elist)
-	      (set! (*s7* 'print-length) old-print-length))
+	     ((memq e elist))
 	   (if (and (number? (length e)) ; with-let + mock-data + length method?
 		    (> (length e) 0))
 	       (format p "~%~{~A~| ~}~%" e)
@@ -1277,7 +1274,6 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 |#
 ;; ideally this would simply vanish, and make no change in the run-time state, but (values) here returns #<unspecified>
 ;;   (let ((a 1) (b 2)) (list (set! a 3) (reflective-probe) b)) -> '(3 2) not '(3 #<unspecified> 2)
-;;   I was too timid when I started s7 and thought (then) that (abs -1 (values)) should be an error
 ;; perhaps if we want it to disappear:
 
 (define-bacro (reflective-probe . body)
