@@ -20,6 +20,7 @@
 		     ("tsort.scm" . "v-sort")
 		     ("tlet.scm" . "v-let")
 		     ("thash.scm" . "v-hash")
+		     ("tmap-hash.scm" . "v-map-hash")
 		     ("tgen.scm" . "v-gen")
 		     ("tall.scm" . "v-all")
 		     ("snd-test.scm" . "v-call")
@@ -51,6 +52,7 @@
 		     ("tlamb.scm" . "v-lamb")
 		     ("thook.scm" . "v-hook")
 		     ("tstar.scm" . "v-star")
+		     ("tmv.scm" . "v-mv")
 		     ))
 
 (define (last-callg)
@@ -89,27 +91,26 @@
 	 (list "repl" "tmock.scm")
 	 (list "repl" "tvect.scm")
 	 (list "repl" "tauto.scm")
-	 (list "repl" "timp.scm")
 	 (list "repl" "texit.scm")
 	 (list "repl" "s7test.scm")
 	 (list "repl" "lt.scm")
-	 (list "repl" "thook.scm")
 	 (list "repl" "dup.scm")
+	 (list "repl" "thook.scm")
 	 (list "repl" "tcopy.scm")
 	 (list "repl" "tread.scm")
-	 (list "repl" "trclo.scm")
 	 (list "repl" "titer.scm")
+	 (list "repl" "trclo.scm")
+	 (list "repl" "tmat.scm")
 	 (list "repl" "tload.scm")
 	 (list "repl" "fbench.scm")
-	 (list "repl" "tmat.scm")
 	 (list "repl" "tsort.scm")
+	 (list "repl" "tio.scm")
 	 (list "repl" "tobj.scm")
 	 (list "repl" "teq.scm")
-	 (list "repl" "tio.scm")
 	 (list "repl" "tmac.scm")
+	 (list "repl" "tclo.scm")
 	 (list "repl" "tcase.scm")
 	 (list "repl" "tlet.scm")
-	 (list "repl" "tclo.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tstar.scm")
 	 (list "repl" "tmap.scm")
@@ -123,13 +124,16 @@
 	 (list "repl" "tset.scm")
 	 (list "repl" "trec.scm")
 	 (list "repl" "tleft.scm")
+	 (list "repl" "tmisc.scm")
 	 (list "repl" "tlamb.scm")
 	 (list "repl" "tgc.scm")
-	 (list "repl" "tmisc.scm")
 	 (list "repl" "thash.scm")
 	 (list "repl" "cb.scm")
+	 (list "repl" "tmap-hash.scm")
+	 (list "repl" "tmv.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
+	 (list "repl" "timp.scm")
 	 (list "snd -l" "snd-test.scm")
 	 (list "snd -l" "full-snd-test.scm")
 	 (list "repl" "tbig.scm")
